SqliteMigrationPlan class

SQLite schema diff result.

Constructors

SqliteMigrationPlan({required List<String> statements, required List<String> warnings, bool requiresRebuild = false})
Creates a migration plan.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether the plan contains no statements, warnings, or rebuilds.
no setter
requiresRebuild bool
Whether the change requires a schema rebuild.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statements List<String>
SQL statements that can be applied directly.
final
warnings List<String>
Human-readable warnings that require operator review.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited