isEmpty property
bool
get
isEmpty
Whether the plan contains no statements, warnings, or rebuilds.
Implementation
bool get isEmpty =>
statements.isEmpty && warnings.isEmpty && !requiresRebuild;
Whether the plan contains no statements, warnings, or rebuilds.
bool get isEmpty =>
statements.isEmpty && warnings.isEmpty && !requiresRebuild;