SqliteMigrationPlanner class

Computes SQLite migration plans from schema diffs or live databases.

Constructors

SqliteMigrationPlanner({SqliteSchemaApplier schemaApplier = const SqliteSchemaApplier(), SqliteSchemaIntrospector schemaIntrospector = const SqliteSchemaIntrospector()})
Creates a SQLite migration planner.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaApplier SqliteSchemaApplier
Helper used to render SQLite DDL statements.
final
schemaIntrospector SqliteSchemaIntrospector
Helper used to introspect live SQLite schemas.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plan({required SchemaDocument from, required SchemaDocument to}) SqliteMigrationPlan
Builds a plan from two schema snapshots.
planFromDatabase({required Database database, required SchemaDocument to}) SqliteMigrationPlan
Builds a plan by introspecting the live database first.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited