SqliteMigrationCli class
Command-line entry point for SQLite migration workflows.
Constructors
- SqliteMigrationCli({SqliteMigrationService? service, CliReadLine? readLine, bool? interactiveInput, GeneratedClientWriter? clientWriter, StringSink? out, StringSink? err})
- Creates a SQLite migration CLI.
Properties
- clientWriter → GeneratedClientWriter
-
Writes generated clients after schema-changing workflows.
final
- err → StringSink
-
Standard error sink.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- out → StringSink
-
Standard output sink.
final
- prompter → CliPrompter
-
Interactive prompt helper.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → SqliteMigrationService
-
Migration service used for planning and applying changes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< String> args) → int - Runs a SQLite migration command.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited