SqliteSchemaApplier class
Builds SQLite DDL statements from schema definitions.
Constructors
- SqliteSchemaApplier()
-
Creates a SQLite schema applier.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addColumnStatement(
String modelName, FieldDefinition field) → String -
Returns an
ALTER TABLE ... ADD COLUMNstatement forfield. -
addColumnStatementForModel(
ModelDefinition model, FieldDefinition field, {SchemaDocument? schema}) → String - Returns an add-column statement using mapped model and field names.
-
apply(
Database database, SchemaDocument schema) → void -
Applies the schema to
databaseusing create-if-missing semantics. -
columnDefinition(
FieldDefinition field, {SchemaDocument? schema}) → String -
Returns a SQLite column definition for
field. -
createImplicitManyToManyTableStatement(
ImplicitManyToManyStorageDefinition storage) → String -
Returns a join-table creation statement for
storage. -
createImplicitManyToManyTableStatements(
SchemaDocument schema) → List< String> - Returns creation statements for implicit many-to-many tables.
-
createTableStatementForModel(
ModelDefinition model, {SchemaDocument? schema}) → String -
Returns a table creation statement for
model. -
createTableStatements(
SchemaDocument schema) → List< String> -
Returns table creation statements for every model in
schema. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sqliteTypeForField(
FieldDefinition field, {SchemaDocument? schema}) → String -
Returns the SQLite column type used for
field. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited